@@ -11,7 +11,7 @@
 static P Lx[1];
 
 /* Define the local data section. */
-static Blk( Rd, 1472 ) = {
+static Blk( Rd, 1480 ) = {
  14,  14, 115, 101, 116,  95, 115, 114,  99, 102, 105, 108, 101, 115, 112,  99,
  60,  60,  47, 104, 111, 109, 101,  47, 112, 105, 101, 114, 114, 101,  47,  83,
 111, 102, 116,  47,  99, 112, 115, 104,  95, 107, 105, 116, 115,  47,  99, 112,
@@ -56,15 +56,16 @@ static Blk( Rd, 1472 ) = {
   4, 119, 105, 116, 104,   3,   3, 101, 110, 100,   9,   9, 111, 116, 104, 101,
 114, 119, 105, 115, 101,   2,   2, 111, 102,   2,   2, 100, 111,   2,   2, 116,
 111,   6,   6, 100, 111, 119, 110, 116, 111,   7,   7,  37, 100, 101, 102, 105,
-110, 101,   3,   3,  37, 105, 102,   6,   6,  37, 105, 102, 100, 101, 102,   8,
-  8,  37, 105, 102, 117, 110, 100, 101, 102,   5,   5,  37, 101, 108, 115, 101,
-  6,   6,  37, 101, 110, 100, 105, 102,   7,   7,  37,  99, 104,  97, 105, 110,
-101,   8,   8,  37, 105, 110,  99, 108, 117, 100, 101,   7,   7,  37, 112, 114,
- 97, 103, 109,  97,   4,   4,  37, 101, 111, 102,   6,   6, 110, 101, 120, 116,
- 99, 104,   8,   8, 112, 117, 116,  95,  99, 104,  97, 114,   4,   4,  73,  78,
- 83,  89,  12,  12, 116, 101, 115, 116,  95, 102, 105, 103, 117, 114, 101, 115,
-  7,   7, 102, 105, 103, 117, 114, 101, 115,   4,   4,  70,  73,  71,  85,  12,
- 12, 105, 110, 115, 121, 109,  98, 111, 108,  95, 115, 114,  99, 255,   0,   0,
+110, 101,   9,   9,  37, 117, 110, 100, 101, 102, 105, 110, 101,   3,   3,  37,
+105, 102,   6,   6,  37, 105, 102, 100, 101, 102,   8,   8,  37, 105, 102, 117,
+110, 100, 101, 102,   5,   5,  37, 101, 108, 115, 101,   6,   6,  37, 101, 110,
+100, 105, 102,   7,   7,  37,  99, 104,  97, 105, 110, 101,   8,   8,  37, 105,
+110,  99, 108, 117, 100, 101,   7,   7,  37, 112, 114,  97, 103, 109,  97,   4,
+  4,  37, 101, 111, 102,   6,   6, 110, 101, 120, 116,  99, 104,   8,   8, 112,
+117, 116,  95,  99, 104,  97, 114,   4,   4,  73,  78,  83,  89,  12,  12, 116,
+101, 115, 116,  95, 102, 105, 103, 117, 114, 101, 115,   7,   7, 102, 105, 103,
+117, 114, 101, 115,   4,   4,  70,  73,  71,  85,  12,  12, 105, 110, 115, 121,
+109,  98, 111, 108,  95, 115, 114,  99, 255,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
@@ -80,30 +81,30 @@ static Blk( Rd, 1472 ) = {
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
-  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,  13,  13,
-112, 114,  97, 103, 109,  97,  95, 109, 115, 116,  97, 116, 101,   4,   4,  80,
- 82,  65,  71,  14,  14, 105, 110,  99, 108, 117, 100, 101,  95, 109, 115, 116,
- 97, 116, 101,   4,   4,  46, 112,  97, 115,   4,   4,  73,  78,  67,  76,  20,
- 20,  32,  79, 112, 101, 110,  32,  69, 114, 114, 111, 114,  32,  40,  82,  84,
- 76,  41,  32,  35,  32,  22,  22,  32, 102, 111, 114,  32, 116, 104, 101,  32,
- 83, 111, 117, 114,  99, 101,  32, 102, 105, 108, 101,  32,  34,   2,   2,  34,
- 46,  15,  15,  32,  82,  84,  76,  32, 109, 101, 115, 115,  97, 103, 101,  32,
- 58,  32,  14,  14, 101, 110, 100, 102, 105, 108, 101,  95, 109, 115, 116,  97,
-116, 101,   8,   8, 105, 110, 115, 121, 109,  98, 111, 108,   4,   4,  77,  65,
- 83,  89,  11,  11, 115, 107, 105, 112,  95, 115, 121, 109,  98, 111, 108,   9,
-  9, 105, 110, 115, 121,  95, 105, 110, 105, 116,   0,   0,  52,  52,  32,  80,
- 32,  65,  32,  83,  32,  45,  32,  80,  46,  32,  87,  79,  76,  70,  69,  82,
- 83,  32,  83,  79,  70,  84,  87,  65,  82,  69,  58,  32,  86,  51,  46,  48,
- 45,  65,  32,  79,  70,  32,  51,  49,  45,  79,  67,  84,  45,  50,  48,  49,
- 52,  32,  19,  19,  67,  80,  65,  83,  95,  67,  79,  77,  80,  73,  76,  69,
- 82,  95,  69,  82,  82,  79,  82,   5,   5,  32,  80,  65,  83,  62,  16,  16,
- 67,  80,  65,  83,  95,  69,  78,  86,  73,  82,  79,  78,  77,  69,  78,  84,
- 22,  22,  32,  80,  65,  83,  32,  67,  65,  78,  78,  79,  84,  32,  79,  80,
- 69,  78,  32,  84,  72,  69,  32,  34,  15,  15,  34,  32,  73,  78,  73,  84,
- 73,  65,  76,  32,  70,  73,  76,  69,  46,  22,  22,  32,  80,  65,  83,  32,
- 67,  65,  78,  78,  79,  84,  32,  79,  80,  69,  78,  32,  84,  72,  69,  32,
- 34,  23,  23,  34,  32,  79,  85,  84,  80,  85,  84,  32,  77,  83,  71,  47,
- 76,  73,  83,  84,  32,  70,  73,  76,  69,  46,   0,   0,   0,   0,   0,   0
+  0,   0,   0,   0,   0,   0,   0,   0,   0,  13,  13, 112, 114,  97, 103, 109,
+ 97,  95, 109, 115, 116,  97, 116, 101,   4,   4,  80,  82,  65,  71,  14,  14,
+105, 110,  99, 108, 117, 100, 101,  95, 109, 115, 116,  97, 116, 101,   4,   4,
+ 46, 112,  97, 115,   4,   4,  73,  78,  67,  76,  20,  20,  32,  79, 112, 101,
+110,  32,  69, 114, 114, 111, 114,  32,  40,  82,  84,  76,  41,  32,  35,  32,
+ 22,  22,  32, 102, 111, 114,  32, 116, 104, 101,  32,  83, 111, 117, 114,  99,
+101,  32, 102, 105, 108, 101,  32,  34,   2,   2,  34,  46,  15,  15,  32,  82,
+ 84,  76,  32, 109, 101, 115, 115,  97, 103, 101,  32,  58,  32,  14,  14, 101,
+110, 100, 102, 105, 108, 101,  95, 109, 115, 116,  97, 116, 101,   8,   8, 105,
+110, 115, 121, 109,  98, 111, 108,   4,   4,  77,  65,  83,  89,  11,  11, 115,
+107, 105, 112,  95, 115, 121, 109,  98, 111, 108,   9,   9, 105, 110, 115, 121,
+ 95, 105, 110, 105, 116,   0,   0,  52,  52,  32,  80,  32,  65,  32,  83,  32,
+ 45,  32,  80,  46,  32,  87,  79,  76,  70,  69,  82,  83,  32,  83,  79,  70,
+ 84,  87,  65,  82,  69,  58,  32,  86,  51,  46,  48,  45,  65,  32,  79,  70,
+ 32,  51,  49,  45,  79,  67,  84,  45,  50,  48,  49,  52,  32,  19,  19,  67,
+ 80,  65,  83,  95,  67,  79,  77,  80,  73,  76,  69,  82,  95,  69,  82,  82,
+ 79,  82,   5,   5,  32,  80,  65,  83,  62,  16,  16,  67,  80,  65,  83,  95,
+ 69,  78,  86,  73,  82,  79,  78,  77,  69,  78,  84,  22,  22,  32,  80,  65,
+ 83,  32,  67,  65,  78,  78,  79,  84,  32,  79,  80,  69,  78,  32,  84,  72,
+ 69,  32,  34,  15,  15,  34,  32,  73,  78,  73,  84,  73,  65,  76,  32,  70,
+ 73,  76,  69,  46,  22,  22,  32,  80,  65,  83,  32,  67,  65,  78,  78,  79,
+ 84,  32,  79,  80,  69,  78,  32,  84,  72,  69,  32,  34,  23,  23,  34,  32,
+ 79,  85,  84,  80,  85,  84,  32,  77,  83,  71,  47,  76,  73,  83,  84,  32,
+ 70,  73,  76,  69,  46,   0,   0,   0
 };
 
 /* Define the local static Initialized section. */
@@ -510,18 +511,19 @@ void PAS_INSMBOL_set_keyword_tree(){
   PAS_INSMBOL_PRC_00000000(Rd.s+685,52,29);
   PAS_INSMBOL_PRC_00000000(Rd.s+689,53,29);
   PAS_INSMBOL_PRC_00000000(Rd.s+697,90,29);
-  PAS_INSMBOL_PRC_00000000(Rd.s+706,92,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+706,91,29);
   Ra.sl[3]=323; /* line # 323 */
-  PAS_INSMBOL_PRC_00000000(Rd.s+711,93,29);
-  PAS_INSMBOL_PRC_00000000(Rd.s+719,94,29);
-  PAS_INSMBOL_PRC_00000000(Rd.s+729,95,29);
-  PAS_INSMBOL_PRC_00000000(Rd.s+736,96,29);
-  PAS_INSMBOL_PRC_00000000(Rd.s+744,99,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+717,92,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+722,93,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+730,94,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+740,95,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+747,96,29);
   Ra.sl[3]=328; /* line # 328 */
-  PAS_INSMBOL_PRC_00000000(Rd.s+753,98,29);
-  PAS_INSMBOL_PRC_00000000(Rd.s+763,100,29);
-  Ra.sl[3]=334; /* line # 334 */
-  PAS_INSMBOL_PRC_00000000(Rd.s+772,101,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+755,99,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+764,98,29);
+  PAS_INSMBOL_PRC_00000000(Rd.s+774,100,29);
+  Ra.sl[3]=335; /* line # 335 */
+  PAS_INSMBOL_PRC_00000000(Rd.s+783,101,29);
   PAS__curr_cntx=Ra.v[0];
 }
 
@@ -535,9 +537,9 @@ void PAS_INSMBOL_PRC_00000001(){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+778;
+  Ra.v[1]=Rd.s+789;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=410; /* line # 410 */
+  Ra.sl[3]=422; /* line # 422 */
   V_sy_ch=P_src_inchar();
   V_sy_cmin=V_sy_ch;
   if (V_sy_ch>=65&&V_sy_ch<=90) V_sy_cmin=(C)((SL)V_sy_ch+32);
@@ -555,17 +557,17 @@ void PAS_INSMBOL_PRC_00000002(){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+786;
+  Ra.v[1]=Rd.s+797;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=419; /* line # 419 */
+  Ra.sl[3]=431; /* line # 431 */
   if (!Lx[0].ub[0]) {
     if (Lx[0].sl[1]<V_sy_string.ub[0]) {
       V_sy_string.c[Lx[0].sl[1]+1]=V_sy_ch;
       Lx[0].sl[1]=Lx[0].sl[1]+1;
     }
     else {
-      Ra.sl[3]=427; /* line # 427 */
-      P_src_error(Rd.s+798,12,2);
+      Ra.sl[3]=439; /* line # 439 */
+      P_src_error(Rd.s+809,12,2);
       Lx[0].ub[0]=1;
     }
   }
@@ -585,16 +587,16 @@ SL PAS_INSMBOL_PRC_00000003(C F_ch){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+802;
+  Ra.v[1]=Rd.s+813;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=438; /* line # 438 */
+  Ra.sl[3]=450; /* line # 450 */
   if (F_ch>=48&&F_ch<=57) Rv0=(SL)F_ch-48;
   else {
     if ((Lx[0].ub[8]&&F_ch>=97)&&F_ch<=102) Rv0=(10+(SL)F_ch)-97;
     else Rv0=-1;
   }
   if ((double)Rv0>=Lx[0].g[2]) Rv0=-2;
-  Ra.sl[3]=443; /* line # 443 */
+  Ra.sl[3]=455; /* line # 455 */
   Ret=Rv0;
   PAS__curr_cntx=Ra.v[0];
   return(Ret);
@@ -613,15 +615,15 @@ SL PAS_INSMBOL_PRC_00000004(C F_ch){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+816;
+  Ra.v[1]=Rd.s+827;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=454; /* line # 454 */
+  Ra.sl[3]=466; /* line # 466 */
   Rv0=PAS_INSMBOL_PRC_00000003(F_ch);
   if (Rv0==-2) {
     Rv0=0;
-    P_src_error(Rd.s+827,16,2);
+    P_src_error(Rd.s+838,16,2);
   }
-  Ra.sl[3]=459; /* line # 459 */
+  Ra.sl[3]=471; /* line # 471 */
   Ret=Rv0;
   PAS__curr_cntx=Ra.v[0];
   return(Ret);
@@ -649,8 +651,9 @@ void P_insymbol_src(){
   register V Rv12;
   UB Rv13;
   UB Rv14;
-  register V Rv15;
-  C Rv16;
+  SL Rv15;
+  register V Rv16;
+  C Rv17;
   register G Rgg;
   register P Lx_Sv;
   Lx_Sv=Lx[0];
@@ -659,9 +662,9 @@ void P_insymbol_src(){
   /* Code of procedure/function */
   Ra.v[6]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s+24;
-  Ra.v[7]=Rd.s+831;
+  Ra.v[7]=Rd.s+842;
   Ra.v[8]=Rd.s+16;
-  Ra.sl[9]=465; /* line # 465 */
+  Ra.sl[9]=477; /* line # 477 */
   while (V_sy_ch==32)
   PAS_INSMBOL_PRC_00000001();
   Rv0=1;
@@ -669,7 +672,7 @@ void P_insymbol_src(){
   ((SL *)Rv1)[2]=((SL *)Rv1)[3];
   switch (Ri.ub[V_sy_cmin]) {
     case 2:
-    case 8:Ra.sl[9]=472; /* line # 472 */
+    case 8:Ra.sl[9]=484; /* line # 484 */
     V_sy_sym.ub[0]=20;
     V_sy_sym.ub[1]=29;
     Rv2=0;
@@ -678,57 +681,57 @@ void P_insymbol_src(){
     Rv5=1.000000000000000E+000;
     Ra.g[2]=1.000000000000000E+001;
     Ra.ub[8]=0;
-    Ra.sl[9]=477; /* line # 477 */
+    Ra.sl[9]=489; /* line # 489 */
     while (Ri.ub[V_sy_cmin]==2){
       V_sy_sym.ub[0]=2;
       Rv6=(double)((SL)V_sy_cmin-48);
       PAS_INSMBOL_PRC_00000001();
-      Ra.sl[9]=482; /* line # 482 */
+      Ra.sl[9]=494; /* line # 494 */
       Rv3=Rv3*1.000000000000000E+001+Rv6;
       Rv2=Rv2+1;
     }
     if (V_sy_sym.ub[0]==2&&V_sy_ch==35) {
-      Ra.sl[9]=488; /* line # 488 */
+      Ra.sl[9]=500; /* line # 500 */
       PAS_INSMBOL_PRC_00000001();
       Rv7=(Rv3>0.0?(SL)(Rv3+0.5):(SL)(Rv3-0.5));
       Rv3=0.000000000000000E-001;
       if (Rv7<2||Rv7>16) {
-        Ra.sl[9]=493; /* line # 493 */
-        P_src_error(Rd.s+798,14,2);
+        Ra.sl[9]=505; /* line # 505 */
+        P_src_error(Rd.s+809,14,2);
         Rv7=10;
       }
       else Ra.g[2]=(double)Rv7;
       Ra.ub[8]=1;
       while (1){
-        Ra.sl[9]=499; /* line # 499 */
+        Ra.sl[9]=511; /* line # 511 */
         Rv6=(double)PAS_INSMBOL_PRC_00000004(V_sy_cmin);
         if (Rv6<0.000000000000000E-001)  break;
         Rv3=Rv3*Ra.g[2]+Rv6;
         PAS_INSMBOL_PRC_00000001();
       }
     }
-    Ra.sl[9]=506; /* line # 506 */
+    Ra.sl[9]=518; /* line # 518 */
     if (V_sy_ch==46) {
       if (P_src_next_char()==46) {
         if (V_sy_sym.ub[0]==20) {
-          Ra.sl[9]=511; /* line # 511 */
+          Ra.sl[9]=523; /* line # 523 */
           PAS_INSMBOL_PRC_00000001();
           V_sy_sym.ub[0]=21;
         }
         else Rv0=0;
       }
       else {
-        Ra.sl[9]=517; /* line # 517 */
+        Ra.sl[9]=529; /* line # 529 */
         PAS_INSMBOL_PRC_00000001();
         if (PAS_INSMBOL_PRC_00000003(V_sy_cmin)<0) Rv0=0;
         else {
-          Ra.sl[9]=522; /* line # 522 */
+          Ra.sl[9]=534; /* line # 534 */
           V_sy_sym.ub[0]=4;
           while (1){
             Rv6=(double)PAS_INSMBOL_PRC_00000004(V_sy_cmin);
             if (Rv6<0.000000000000000E-001)  break;
             PAS_INSMBOL_PRC_00000001();
-            Ra.sl[9]=527; /* line # 527 */
+            Ra.sl[9]=539; /* line # 539 */
             Rv5=Rv5/Ra.g[2];
             Rv3=Rv3+Rv5*Rv6;
             Rv2=Rv2+1;
@@ -736,93 +739,93 @@ void P_insymbol_src(){
         }
       }
     }
-    Ra.sl[9]=535; /* line # 535 */
+    Ra.sl[9]=547; /* line # 547 */
     if (V_sy_sym.ub[0]!=20&&V_sy_sym.ub[0]!=21) {
       if (V_sy_cmin==101||Ra.ub[8]&&V_sy_cmin==36) {
         V_sy_sym.ub[0]=4;
-        Ra.sl[9]=540; /* line # 540 */
+        Ra.sl[9]=552; /* line # 552 */
         PAS_INSMBOL_PRC_00000001();
         if (V_sy_ch==43||V_sy_ch==45) {
           if (V_sy_ch==45) Rv4=1.000000000000000E+000/Rv4;
           PAS_INSMBOL_PRC_00000001();
         }
-        Ra.sl[9]=546; /* line # 546 */
+        Ra.sl[9]=558; /* line # 558 */
         Rv8=0;
         while (Ri.ub[V_sy_cmin]==2){
           Rv8=Rv8*10+((SL)V_sy_ch-48);
           PAS_INSMBOL_PRC_00000001();
         }
-        Ra.sl[9]=552; /* line # 552 */
+        Ra.sl[9]=564; /* line # 564 */
         if (Rv8>307) {
-          P_src_error(Rd.s+798,11,2);
+          P_src_error(Rd.s+809,11,2);
           Rv8=307;
           Rv3=1.000000000000000E+000;
         }
         else {
-          Ra.sl[9]=559; /* line # 559 */
+          Ra.sl[9]=571; /* line # 571 */
           if (Rv8>38) Rv2=8;
         }
         Rv5=1.000000000000000E+000;
         while (Rv8!=0)
         if (Rv8&1) {
-          Ra.sl[9]=565; /* line # 565 */
+          Ra.sl[9]=577; /* line # 577 */
           Rv8=Rv8-1;
           Rv5=Rv5*Rv4;
         }
         else {
-          Ra.sl[9]=570; /* line # 570 */
+          Ra.sl[9]=582; /* line # 582 */
           Rv8=Rv8/2;
           Rv4=Rv4*Rv4;
         }
         Rv3=Rv3*Rv5;
       }
-      Ra.sl[9]=577; /* line # 577 */
+      Ra.sl[9]=589; /* line # 589 */
       if (V_sy_sym.ub[0]==2) {
         if (Rv3<=4.294967295000001E+009&&Rv3>=-2.147483648000000E+009) {
           if (Rv3>2.147483647000000E+009) V_sy_ival=(int)(4.294967295000001E+009-
           Rv3)+1;
           else V_sy_ival=(int)(Rv3);
-          Ra.sl[9]=582; /* line # 582 */
+          Ra.sl[9]=594; /* line # 594 */
           V_sy_rval=(double)V_sy_ival;
           if ((V_sy_label_flag&&Ri.ub[V_sy_cmin]==5)&&P_src_next_char()!=61) {
             PAS_INSMBOL_PRC_00000001();
-            Ra.sl[9]=587; /* line # 587 */
+            Ra.sl[9]=599; /* line # 599 */
             P_ide_int_label();
             V_sy_sym.ub[0]=1;
           }
         }
         else {
-          Ra.sl[9]=593; /* line # 593 */
+          Ra.sl[9]=605; /* line # 605 */
           V_sy_ival=0;
           if (Rv2>7) V_sy_sym.ub[0]=4;
           else V_sy_sym.ub[0]=3;
         }
       }
       else {
-        Ra.sl[9]=598; /* line # 598 */
+        Ra.sl[9]=610; /* line # 610 */
         if (Rv2<=7) V_sy_sym.ub[0]=3;
       }
       V_sy_rval=Rv3;
       Rv0=0;
     }
     break;
-    case 3:Ra.sl[9]=606; /* line # 606 */
+    case 3:Ra.sl[9]=618; /* line # 618 */
     V_sy_ident.ub[0]=0;
     while (1){
       if (V_sy_ident.ub[0]<31) {
-        Ra.sl[9]=613; /* line # 613 */
+        Ra.sl[9]=625; /* line # 625 */
         V_sy_ident.ub[0]=V_sy_ident.ub[0]+1;
         V_sy_ident.c[V_sy_ident.ub[0]]=V_sy_cmin;
       }
       PAS_INSMBOL_PRC_00000001();
       if (Ri.ub[V_sy_cmin]!=3&&Ri.ub[V_sy_cmin]!=2)  break;
     }
-    Ra.sl[9]=619; /* line # 619 */
+    Ra.sl[9]=631; /* line # 631 */
     Rv9=V_keyword_tree;
     while (1){
       Rv10=Rv9;
       Rv11=P_match(V_sy_ident.s,Rv10);
-      Ra.sl[9]=624; /* line # 624 */
+      Ra.sl[9]=636; /* line # 636 */
       if (Rv11!=0) {
         if (Rv11>0) Rv9=((V *)Rv10)[9];
         else Rv9=((V *)Rv10)[8];
@@ -830,108 +833,168 @@ void P_insymbol_src(){
       if (Rv11==0||Rv9==NULL)  break;
     }
     if (Rv9==NULL) {
-      Ra.sl[9]=630; /* line # 630 */
+      Ra.sl[9]=642; /* line # 642 */
       if ((V_sy_label_flag&&Ri.ub[V_sy_cmin]==5)&&P_src_next_char()!=61) {
         PAS_INSMBOL_PRC_00000001();
         V_sy_sym.ub[0]=1;
       }
       else {
-        Ra.sl[9]=637; /* line # 637 */
+        Ra.sl[9]=649; /* line # 649 */
         V_sy_sym.ub[0]=0;
       }
       V_sy_sym.ub[1]=29;
     }
     else memcpy(V_sy_sym.s,Rv9+40,2);
-    Ra.sl[9]=642; /* line # 642 */
+    Ra.sl[9]=654; /* line # 654 */
     Rv0=0;
     break;
-    case 4:Ra.sl[9]=647; /* line # 647 */
+    case 4:Ra.sl[9]=659; /* line # 659 */
     V_sy_sym.ub[1]=29;
     Rv12=V_src_control;
     Rv13=(1024&((UL *)Rv12)[52])!=0;
-    Ra.sl[9]=652; /* line # 652 */
+    Ra.sl[9]=664; /* line # 664 */
     ((UB *)Rv12)[212]=4;
     ((UL *)Rv12)[52]=((UL *)Rv12)[52]|1024;
     V_sy_sym.ub[0]=5;
     Ra.sl[1]=1;
     Ra.ub[0]=0;
-    Ra.sl[9]=657; /* line # 657 */
+    Ra.sl[9]=669; /* line # 669 */
     Rv14=1;
     while (Rv14){
       PAS_INSMBOL_PRC_00000001();
       while (Ri.ub[V_sy_cmin]==10)
       PAS_INSMBOL_PRC_00000001();
-      Ra.sl[9]=662; /* line # 662 */
+      Ra.sl[9]=674; /* line # 674 */
       if (Ri.ub[V_sy_cmin]==9) Rv14=0;
       if (V_sy_ch==39) {
         ((UB *)V_src_control)[212]=0;
         PAS_INSMBOL_PRC_00000001();
-        Ra.sl[9]=667; /* line # 667 */
+        Ra.sl[9]=679; /* line # 679 */
         if (V_sy_ch==39) {
           ((UB *)V_src_control)[212]=4;
           PAS_INSMBOL_PRC_00000002();
         }
         else {
-          Ra.sl[9]=672; /* line # 672 */
+          Ra.sl[9]=684; /* line # 684 */
           Rv14=0;
         }
       }
-      else PAS_INSMBOL_PRC_00000002();
+      else {
+        if (V_sy_ch==92) {
+          PAS_INSMBOL_PRC_00000001();
+          Ra.sl[9]=689; /* line # 689 */
+          switch (V_sy_cmin) {
+            case 34:
+            case 39:
+            case 92:break;
+            case 97:V_sy_ch=7;
+            break;
+            case 98:V_sy_ch=8;
+            break;
+            case 101:V_sy_ch=27;
+            break;
+            case 102:Ra.sl[9]=694; /* line # 694 */
+            V_sy_ch=12;
+            break;
+            case 110:V_sy_ch=10;
+            break;
+            case 114:V_sy_ch=13;
+            break;
+            case 116:V_sy_ch=9;
+            break;
+            case 118:V_sy_ch=11;
+            break;
+            case 122:Ra.sl[9]=699; /* line # 699 */
+            V_sy_ch=0;
+            break;
+            case 48:
+            case 49:
+            case 50:
+            case 51:
+            case 52:
+            case 53:
+            case 54:
+            case 55:
+            case 56:
+            case 57:Rv11=(SL)V_sy_cmin-48;
+            PAS_INSMBOL_PRC_00000001();
+            Rv15=3;
+            Ra.sl[9]=704; /* line # 704 */
+            while ((Rv15>0&&V_sy_cmin>=48)&&V_sy_cmin<=57){
+              Rv11=(Rv11*10+(SL)V_sy_cmin)-48;
+              PAS_INSMBOL_PRC_00000001();
+            }
+            Ra.sl[9]=709; /* line # 709 */
+            if (Rv11<=255) V_sy_ch=(C)Rv11;
+            else {
+              V_sy_ch=32;
+              P_src_error(Rd.s+809,17,2);
+            }
+            break;
+            default:V_sy_ch=32;
+            P_src_error(Rd.s+809,18,2);
+            break;
+          }
+          Ra.sl[9]=715; /* line # 715 */
+          PAS_INSMBOL_PRC_00000002();
+        }
+        else PAS_INSMBOL_PRC_00000002();
+      }
     }
     V_sy_string.ub[1]=Ra.sl[1] -1;
-    Ra.sl[9]=677; /* line # 677 */
+    Ra.sl[9]=720; /* line # 720 */
     Rv0=0;
-    Rv15=V_src_control;
+    Rv16=V_src_control;
     if (!Rv13) {
-      ((UL *)Rv15)[52]=((UL *)Rv15)[52]&~1024;
-      Ra.sl[9]=682; /* line # 682 */
+      ((UL *)Rv16)[52]=((UL *)Rv16)[52]&~1024;
+      Ra.sl[9]=725; /* line # 725 */
       if (Ri.ub[V_sy_cmin]==10) V_sy_ch=32;
     }
     break;
-    case 5:Ra.sl[9]=688; /* line # 688 */
+    case 5:Ra.sl[9]=731; /* line # 731 */
     PAS_INSMBOL_PRC_00000001();
     V_sy_sym.ub[1]=29;
     if (V_sy_ch==61) V_sy_sym.ub[0]=23;
     else {
-      Ra.sl[9]=693; /* line # 693 */
+      Ra.sl[9]=736; /* line # 736 */
       V_sy_sym.ub[0]=22;
       Rv0=0;
     }
     break;
-    case 6:Ra.sl[9]=700; /* line # 700 */
+    case 6:Ra.sl[9]=743; /* line # 743 */
     PAS_INSMBOL_PRC_00000001();
     V_sy_sym.ub[0]=10;
     if (V_sy_ch==61) V_sy_sym.ub[1]=15;
     else {
       if (V_sy_ch==62) V_sy_sym.ub[1]=18;
       else {
-        Ra.sl[9]=707; /* line # 707 */
+        Ra.sl[9]=750; /* line # 750 */
         V_sy_sym.ub[1]=14;
         Rv0=0;
       }
     }
     break;
-    case 7:Ra.sl[9]=714; /* line # 714 */
+    case 7:Ra.sl[9]=757; /* line # 757 */
     PAS_INSMBOL_PRC_00000001();
     V_sy_sym.ub[0]=10;
     if (V_sy_ch==61) V_sy_sym.ub[1]=16;
     else {
-      Ra.sl[9]=719; /* line # 719 */
+      Ra.sl[9]=762; /* line # 762 */
       V_sy_sym.ub[1]=17;
       Rv0=0;
     }
     break;
-    case 11:Ra.sl[9]=726; /* line # 726 */
-    Rv16=V_sy_ch;
+    case 11:Ra.sl[9]=769; /* line # 769 */
+    Rv17=V_sy_ch;
     PAS_INSMBOL_PRC_00000001();
-    if (V_sy_ch==Rv16) {
+    if (V_sy_ch==Rv17) {
       V_sy_sym.ub[0]=9;
-      Ra.sl[9]=731; /* line # 731 */
+      Ra.sl[9]=774; /* line # 774 */
       V_sy_sym.ub[1]=13;
     }
     else {
       V_sy_sym.ub[0]=13;
-      Ra.sl[9]=736; /* line # 736 */
+      Ra.sl[9]=779; /* line # 779 */
       V_sy_sym.ub[1]=21;
       Rv0=0;
     }
@@ -948,52 +1011,52 @@ void P_insymbol_src(){
     case 23:
     case 24:
     case 25:
-    case 26:Ra.sl[9]=742; /* line # 742 */
+    case 26:Ra.sl[9]=785; /* line # 785 */
     memcpy(V_sy_sym.s,(Ri.s+Ri.ub[V_sy_cmin]*2+106),2);
     break;
     case 16:PAS_INSMBOL_PRC_00000001();
-    Ra.sl[9]=747; /* line # 747 */
+    Ra.sl[9]=790; /* line # 790 */
     if (V_sy_ch==42) {
       V_sy_sym.ub[0]=7;
       V_sy_sym.ub[1]=5;
     }
     else {
-      Ra.sl[9]=754; /* line # 754 */
+      Ra.sl[9]=797; /* line # 797 */
       memcpy(V_sy_sym.s,Ri.s+138,2);
       Rv0=0;
     }
     break;
-    case 22:Ra.sl[9]=761; /* line # 761 */
+    case 22:Ra.sl[9]=804; /* line # 804 */
     PAS_INSMBOL_PRC_00000001();
     if (V_sy_ch==62) {
       V_sy_sym.ub[0]=26;
       V_sy_sym.ub[1]=29;
     }
     else {
-      Ra.sl[9]=769; /* line # 769 */
+      Ra.sl[9]=812; /* line # 812 */
       memcpy(V_sy_sym.s,Ri.s+150,2);
       Rv0=0;
     }
     break;
-    case 9:Ra.sl[9]=776; /* line # 776 */
+    case 9:Ra.sl[9]=819; /* line # 819 */
     V_sy_sym.ub[0]=101;
     V_sy_sym.ub[1]=29;
     break;
-    case 10:Ra.sl[9]=782; /* line # 782 */
+    case 10:Ra.sl[9]=825; /* line # 825 */
     V_sy_sym.ub[0]=88;
     V_sy_sym.ub[1]=29;
     Rv0=0;
     V_sy_ch=32;
     break;
-    default:Ra.sl[9]=789; /* line # 789 */
+    default:Ra.sl[9]=832; /* line # 832 */
     V_sy_sym.ub[0]=102;
     V_sy_sym.ub[1]=29;
     Rv0=0;
-    if (V_sy_ch!=32) P_src_error(Rd.s+798,13,2);
+    if (V_sy_ch!=32) P_src_error(Rd.s+809,13,2);
     V_sy_ch=32;
     break;
   }
-  Ra.sl[9]=796; /* line # 796 */
+  Ra.sl[9]=839; /* line # 839 */
   if (Rv0) PAS_INSMBOL_PRC_00000001();
   PAS__curr_cntx=Ra.v[6];
   Lx[0]=Lx_Sv;
@@ -1024,54 +1087,54 @@ void PAS_INSMBOL_PRC_00000005(V F_p_src){
 
   /* Code of procedure/function */
   Ra.ub[0]=255;
-  PAS__STR_TO_STR(Ra.s,Rd.s+845);
+  PAS__STR_TO_STR(Ra.s,Rd.s+856);
   Ra.ub[257]=255;
-  PAS__STR_TO_STR(Ra.s+257,Rd.s+845);
+  PAS__STR_TO_STR(Ra.s+257,Rd.s+856);
   Ra.ub[514]=255;
-  PAS__STR_TO_STR(Ra.s+514,Rd.s+845);
+  PAS__STR_TO_STR(Ra.s+514,Rd.s+856);
   Ra.ub[771]=255;
-  PAS__STR_TO_STR(Ra.s+771,Rd.s+845);
+  PAS__STR_TO_STR(Ra.s+771,Rd.s+856);
   Ra.v[257]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s+1028;
-  Ra.v[258]=Rd.s+1102;
+  Ra.v[258]=Rd.s+1113;
   Ra.v[259]=Rd.s+16;
-  Ra.sl[260]=890; /* line # 890 */
+  Ra.sl[260]=933; /* line # 933 */
   Rv0=V_sy_label_flag;
   V_sy_label_flag=0;
   Rv1=F_p_src;
   Rv2=((UL *)Rv1)[52];
-  Ra.sl[260]=895; /* line # 895 */
+  Ra.sl[260]=938; /* line # 938 */
   while (V_sy_sym.ub[0]==0){
     Rv3=0;
     Rv4=0;
     while (1){
-      Ra.sl[260]=900; /* line # 900 */
+      Ra.sl[260]=943; /* line # 943 */
       Rv3=P_match(V_sy_ident.s,(Ri.s+Rv4*32+160))==0;
       if (Rv3||Rv4==21)  break;
       Rv4=Rv4+1;
     }
     P_insymbol_src();
-    Ra.sl[260]=905; /* line # 905 */
+    Ra.sl[260]=948; /* line # 948 */
     switch (Rv4) {
       case 0:if (V_sy_sym.ub[0]==5) {
         if (V_sy_ident.ub[0]>0) {
-          Ra.sl[260]=910; /* line # 910 */
+          Ra.sl[260]=953; /* line # 953 */
           Rv5=V_lst_current;
           if (((UB *)((V *)Rv5)[1])[1]>0) P_lst_eoln();
-          Ra.sl[260]=915; /* line # 915 */
+          Ra.sl[260]=958; /* line # 958 */
           PAS__STR_TO_STR(Ra.s,V_sy_string.s);
           P_insymbol_src();
           if (((V *)Rv5)[2]!=NULL) PAS__STR_TO_STR(Ra.s+257,((V *)Rv5)[2]);
           if (((V *)Rv5)[4]!=NULL) PAS__STR_TO_STR(Ra.s+514,((V *)Rv5)[4]);
           if (((V *)Rv5)[5]!=NULL) PAS__STR_TO_STR(Ra.s+771,((V *)Rv5)[5]);
-          Ra.sl[260]=921; /* line # 921 */
+          Ra.sl[260]=964; /* line # 964 */
           P_lst_open(&V_lst_current, Ra.s,Ra.s+257,Ra.s+514,Ra.s+771,132,-1,0,0,0,
           &Rv6);
-          Ra.sl[260]=933; /* line # 933 */
+          Ra.sl[260]=976; /* line # 976 */
           if (Rv6!=0) {
-            if (!V_sy_init_mod) P_src_error(Rd.s+1119,905,2);
+            if (!V_sy_init_mod) P_src_error(Rd.s+1130,905,2);
             else {
-              Ra.sl[260]=938; /* line # 938 */
+              Ra.sl[260]=981; /* line # 981 */
               Rv2=Rv2&~1;
             }
           }
@@ -1081,7 +1144,7 @@ void PAS_INSMBOL_PRC_00000005(V F_p_src){
           }
         }
         else {
-          Ra.sl[260]=946; /* line # 946 */
+          Ra.sl[260]=989; /* line # 989 */
           Rv2=Rv2&~1;
         }
       }
@@ -1090,32 +1153,32 @@ void PAS_INSMBOL_PRC_00000005(V F_p_src){
         Rv2=Rv2|1;
       }
       break;
-      case 1:Ra.sl[260]=954; /* line # 954 */
+      case 1:Ra.sl[260]=997; /* line # 997 */
       Rv2=Rv2&~1;
       break;
       case 2:Rv2=Rv2|32;
       break;
       case 3:Rv2=Rv2&~32;
       break;
-      case 4:Ra.sl[260]=961; /* line # 961 */
+      case 4:Ra.sl[260]=1004; /* line # 1004 */
       if (V_sy_sym.ub[0]==22) P_insymbol_src();
       if (V_sy_sym.ub[0]==2) {
         ((SL *)Rv1)[6]=V_sy_ival;
         P_insymbol_src();
       }
       else {
-        Ra.sl[260]=967; /* line # 967 */
+        Ra.sl[260]=1010; /* line # 1010 */
         ((SL *)Rv1)[6]=1;
       }
       break;
-      case 5:Ra.sl[260]=972; /* line # 972 */
+      case 5:Ra.sl[260]=1015; /* line # 1015 */
       if (V_sy_sym.ub[0]==22) P_insymbol_src();
       if (V_sy_sym.ub[0]==2) {
         ((SL *)Rv1)[9]=V_sy_ival;
         P_insymbol_src();
       }
       else {
-        Ra.sl[260]=978; /* line # 978 */
+        Ra.sl[260]=1021; /* line # 1021 */
         ((SL *)Rv1)[9]=1;
       }
       if (V_sy_sym.ub[0]==22) P_insymbol_src();
@@ -1125,7 +1188,7 @@ void PAS_INSMBOL_PRC_00000005(V F_p_src){
       }
       else((SL *)Rv1)[10]=255;
       break;
-      case 6:Ra.sl[260]=985; /* line # 985 */
+      case 6:Ra.sl[260]=1028; /* line # 1028 */
       V_cmp_macf=1;
       break;
       case 7:V_cmp_macf=0;
@@ -1134,28 +1197,28 @@ void PAS_INSMBOL_PRC_00000005(V F_p_src){
       break;
       case 9:V_cmp_cobj=0;
       break;
-      case 10:Ra.sl[260]=992; /* line # 992 */
+      case 10:Ra.sl[260]=1035; /* line # 1035 */
       if (V_sy_sym.ub[0]==5) {
         if (V_sy_ident.ub[0]>0) {
           if (V_pas_obj!=NULL) P_binary_objf_close();
           Rv7=V_sy_string.ub[1];
           V_pas_obj=PAS__NEW((SL)Rv7+2);
           ((UB *)V_pas_obj)[0]=Rv7;
-          Ra.sl[260]=997; /* line # 997 */
+          Ra.sl[260]=1040; /* line # 1040 */
           PAS__STR_TO_STR(V_pas_obj,V_sy_string.s);
           P_insymbol_src();
           V_cmp_objf=1;
         }
-        else P_src_error(Rd.s+1119,904,4);
+        else P_src_error(Rd.s+1130,904,4);
       }
       else {
-        Ra.sl[260]=1003; /* line # 1003 */
+        Ra.sl[260]=1046; /* line # 1046 */
         if (V_cmp_objf) P_binary_objf_close();
         V_cmp_objf=0;
       }
       break;
       case 11:if (V_cmp_objf) {
-        Ra.sl[260]=1009; /* line # 1009 */
+        Ra.sl[260]=1052; /* line # 1052 */
         P_binary_objf_close();
         V_cmp_objf=0;
       }
@@ -1164,38 +1227,38 @@ void PAS_INSMBOL_PRC_00000005(V F_p_src){
       break;
       case 13:V_cmp_bltt=0;
       break;
-      case 14:Ra.sl[260]=1016; /* line # 1016 */
+      case 14:Ra.sl[260]=1059; /* line # 1059 */
       if (V_sy_sym.ub[0]==2) {
         V_cmp_traceopt=V_sy_ival;
-        Ra.sl[260]=1021; /* line # 1021 */
+        Ra.sl[260]=1064; /* line # 1064 */
         P_insymbol_src();
       }
-      else P_src_error(Rd.s+1119,906,3);
+      else P_src_error(Rd.s+1130,906,3);
       break;
       case 15:V_cmp_debugopt=1;
       break;
-      case 16:Ra.sl[260]=1026; /* line # 1026 */
+      case 16:Ra.sl[260]=1069; /* line # 1069 */
       V_cmp_debugopt=0;
       break;
       case 17:V_cmp_range=1;
       break;
       case 18:V_cmp_range=0;
       break;
-      case 19:Ra.sl[260]=1031; /* line # 1031 */
+      case 19:Ra.sl[260]=1074; /* line # 1074 */
       P_generation_pragma();
       break;
       case 20:V_cmp_cmpdbg=1;
       break;
       case 21:V_cmp_cmpdbg=0;
       break;
-      default:Ra.sl[260]=1037; /* line # 1037 */
-      P_src_error_s(Rd.s+1119,901,1, V_sy_ident.s,NULL);
+      default:Ra.sl[260]=1080; /* line # 1080 */
+      P_src_error_s(Rd.s+1130,901,1, V_sy_ident.s,NULL);
       break;
     }
     if (V_sy_sym.ub[0]==18) P_insymbol_src();
   }
-  if (V_sy_sym.ub[0]!=19) P_src_error(Rd.s+1119,21,2);
-  Ra.sl[260]=1042; /* line # 1042 */
+  if (V_sy_sym.ub[0]!=19) P_src_error(Rd.s+1130,21,2);
+  Ra.sl[260]=1085; /* line # 1085 */
   ((UL *)Rv1)[52]=Rv2;
   V_sy_label_flag=Rv0;
   PAS__curr_cntx=Ra.v[257];
@@ -1218,87 +1281,87 @@ void PAS_INSMBOL_PRC_00000006(UB F_bincl, UB F_bnsferr){
   Ra.ub[0]=255;
   Ra.v[65]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s+260;
-  Ra.v[66]=Rd.s+1123;
+  Ra.v[66]=Rd.s+1134;
   Ra.v[67]=Rd.s+16;
-  Ra.sl[68]=1060; /* line # 1060 */
+  Ra.sl[68]=1103; /* line # 1103 */
   if (V_sy_sym.ub[0]==5) {
     Rv0=NULL;
     PAS__STR_TO_STR(Ra.s,V_sy_string.s);
-    Ra.sl[68]=1065; /* line # 1065 */
+    Ra.sl[68]=1108; /* line # 1108 */
     Rv1=PAS__NINDEX_CHA(Ra.s+2,(SL)Ra.ub[1],46,-1,-1,1);
-    if (Rv1==0) PAS__STR_TO_STR(Ra.s,PAS__CON_STR_STR(Ra.s+276,Ra.s,Rd.s+1139));
+    if (Rv1==0) PAS__STR_TO_STR(Ra.s,PAS__CON_STR_STR(Ra.s+276,Ra.s,Rd.s+1150));
     P_insymbol_src();
     P_src_open(&Rv0, Ra.s,0, &Rv2);
     if (Rv2==0) {
-      Ra.sl[68]=1071; /* line # 1071 */
+      Ra.sl[68]=1114; /* line # 1114 */
       Rv3=Rv0;
       ((V *)Rv3)[1]=V_src_control;
       ((SL *)Rv3)[5]=((SL *)V_src_control)[5];
       if (F_bincl) ((SL *)Rv3)[5]=((SL *)Rv3)[5]+1;
-      Ra.sl[68]=1076; /* line # 1076 */
+      Ra.sl[68]=1119; /* line # 1119 */
       ((SL *)Rv3)[6]=((SL *)V_src_control)[6];
       ((SL *)Rv3)[4]=((SL *)V_src_control)[4];
       ((SL *)Rv3)[9]=((SL *)V_src_control)[9];
       ((SL *)Rv3)[10]=((SL *)V_src_control)[10];
       ((UL *)Rv3)[52]=((UL *)Rv3)[52]|((UL *)V_src_control)[52]&103;
-      Ra.sl[68]=1084; /* line # 1084 */
+      Ra.sl[68]=1127; /* line # 1127 */
       if (V_sy_sym.ub[0]==18) {
         P_insymbol_src();
         PAS_INSMBOL_PRC_00000005(Rv0);
       }
       else {
-        Ra.sl[68]=1090; /* line # 1090 */
-        if (V_sy_sym.ub[0]!=19) P_src_error(Rd.s+1147,21,2);
+        Ra.sl[68]=1133; /* line # 1133 */
+        if (V_sy_sym.ub[0]!=19) P_src_error(Rd.s+1158,21,2);
       }
       if (!F_bincl) P_src_end_of_line();
       V_src_control=Rv0;
       if (V_cmp_trace>0) V_cmp_tracecount=0;
       P_compile_set_title();
-      Ra.sl[68]=1095; /* line # 1095 */
+      Ra.sl[68]=1138; /* line # 1138 */
       P_set_srcfilespc((SL)F_bincl);
       V_sy_ch=32;
       V_sy_sym.ub[0]=99;
       if (!F_bincl) {
-        Ra.sl[68]=1100; /* line # 1100 */
+        Ra.sl[68]=1143; /* line # 1143 */
         Rv4=V_src_control;
         Rv0=((V *)Rv4)[1];
         ((V *)Rv4)[1]=((V *)Rv0)[1];
-        Ra.sl[68]=1105; /* line # 1105 */
+        Ra.sl[68]=1148; /* line # 1148 */
         P_src_close(&Rv0,1);
       }
     }
     else {
       P_lst_newline();
-      Ra.sl[68]=1110; /* line # 1110 */
+      Ra.sl[68]=1153; /* line # 1153 */
       PAS__SELECT_OUT(PAS__f_output);
-      PAS__WRITE_STR(Rd.s+1151,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1162,-1,-1,32);
       PAS__WRITE_INT(Rv2,3,0);
       PAS__WRITE_EOLN();
       P_lst_newline();
       PAS__SELECT_OUT(PAS__f_output);
-      PAS__WRITE_STR(Rd.s+1173,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1184,-1,-1,32);
       PAS__WRITE_STR(Ra.s,-1,-1,32);
-      PAS__WRITE_STR(Rd.s+1197,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1208,-1,-1,32);
       PAS__WRITE_EOLN();
       PAS__GET_RTLMSG(Rv2, Ra.s);
       P_lst_newline();
-      Ra.sl[68]=1115; /* line # 1115 */
+      Ra.sl[68]=1158; /* line # 1158 */
       PAS__SELECT_OUT(PAS__f_output);
-      PAS__WRITE_STR(Rd.s+1201,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1212,-1,-1,32);
       PAS__WRITE_STR(Ra.s,-1,-1,32);
       PAS__WRITE_EOLN();
       while ((V_sy_sym.ub[0]!=19&&V_sy_sym.ub[0]!=89)&&V_sy_sym.ub[0]!=101)
       P_insymbol_src();
       if (F_bnsferr) {
-        Ra.sl[68]=1120; /* line # 1120 */
-        P_src_error(Rd.s+1147,902,4);
+        Ra.sl[68]=1163; /* line # 1163 */
+        P_src_error(Rd.s+1158,902,4);
       }
-      else P_src_error(Rd.s+1147,902,3);
+      else P_src_error(Rd.s+1158,902,3);
     }
   }
   else {
-    Ra.sl[68]=1125; /* line # 1125 */
-    P_src_error(Rd.s+1147,903,4);
+    Ra.sl[68]=1168; /* line # 1168 */
+    P_src_error(Rd.s+1158,903,4);
   }
   PAS__curr_cntx=Ra.v[65];
 }
@@ -1316,21 +1379,21 @@ void PAS_INSMBOL_PRC_00000007(){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+1218;
+  Ra.v[1]=Rd.s+1229;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=1134; /* line # 1134 */
+  Ra.sl[3]=1177; /* line # 1177 */
   P_set_srcfilespc(-1);
   Rv0=V_src_control;
   if (((V *)Rv0)[1]==NULL) V_sy_sym.ub[0]=89;
   else {
-    Ra.sl[3]=1140; /* line # 1140 */
+    Ra.sl[3]=1183; /* line # 1183 */
     Rv1=V_src_control;
     V_src_control=((V *)Rv1)[1];
     P_src_close(&Rv1,1);
     V_sy_ch=32;
     P_compile_set_title();
   }
-  Ra.sl[3]=1146; /* line # 1146 */
+  Ra.sl[3]=1189; /* line # 1189 */
   if (V_cmp_trace>0) V_cmp_tracecount=0;
   if (V_sy_sym.ub[0]==89) V_pas_compile=0;
   PAS__curr_cntx=Ra.v[0];
@@ -1348,27 +1411,27 @@ void P_insymbol(){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+1234;
+  Ra.v[1]=Rd.s+1245;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=1173; /* line # 1173 */
+  Ra.sl[3]=1216; /* line # 1216 */
   P_insymbol_src();
   while (V_sy_sym.ub[0]>=98){
     Rv0=V_sy_sym.ub[0];
     if (V_sy_sym.ub[0]!=101) {
-      Ra.sl[3]=1178; /* line # 1178 */
+      Ra.sl[3]=1221; /* line # 1221 */
       P_insymbol_src();
     }
     switch (Rv0) {
       case 98:
       case 99:PAS_INSMBOL_PRC_00000006(Rv0==98, V_sy_init_mod);
       break;
-      case 101:Ra.sl[3]=1183; /* line # 1183 */
+      case 101:Ra.sl[3]=1226; /* line # 1226 */
       PAS_INSMBOL_PRC_00000007();
       break;
       case 100:PAS_INSMBOL_PRC_00000005(V_src_control);
       break;
-      default:Ra.sl[3]=1197; /* line # 1197 */
-      P_src_error(Rd.s+1246,997,3);
+      default:Ra.sl[3]=1240; /* line # 1240 */
+      P_src_error(Rd.s+1257,997,3);
       break;
     }
     if (V_sy_sym.ub[0]!=89) P_insymbol_src();
@@ -1386,30 +1449,30 @@ void P_skip_symbol(UB F_tosymbol, UB F_errflg){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+1250;
+  Ra.v[1]=Rd.s+1261;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=1207; /* line # 1207 */
+  Ra.sl[3]=1250; /* line # 1250 */
   while (V_sy_sym.ub[0]!=F_tosymbol&&V_sy_sym.ub[0]!=89){
     P_insymbol();
     switch (V_sy_sym.ub[0]) {
       case 42:
       case 55:
       case 57:
-      case 72:Ra.sl[3]=1214; /* line # 1214 */
+      case 72:Ra.sl[3]=1257; /* line # 1257 */
       P_skip_symbol(73,0);
       P_insymbol();
       break;
       case 14:P_skip_symbol(15,0);
       P_insymbol();
       break;
-      case 16:Ra.sl[3]=1222; /* line # 1222 */
+      case 16:Ra.sl[3]=1265; /* line # 1265 */
       P_skip_symbol(17,0);
       P_insymbol();
       break;
       case 49:P_skip_symbol(50,0);
       P_insymbol();
       break;
-      case 73:Ra.sl[3]=1229; /* line # 1229 */
+      case 73:Ra.sl[3]=1272; /* line # 1272 */
       if (F_tosymbol==47||F_errflg) goto L_l_0;
       break;
       default:break;
@@ -1431,46 +1494,46 @@ void P_insy_init(){
   /* Code of procedure/function */
   Ra.v[0]=PAS__curr_cntx;
   PAS__curr_cntx=Ra.s;
-  Ra.v[1]=Rd.s+1263;
+  Ra.v[1]=Rd.s+1274;
   Ra.v[2]=Rd.s+16;
-  Ra.sl[3]=1243; /* line # 1243 */
-  P_lst_g_init(Rd.s+1274,Rd.s+1276,&Rv0);
+  Ra.sl[3]=1286; /* line # 1286 */
+  P_lst_g_init(Rd.s+1285,Rd.s+1287,&Rv0);
   if (Rv0==0) {
-    Ra.sl[3]=1248; /* line # 1248 */
-    P_err_init(Rd.s+1330);
-    P_src_init(Rd.s+1351,Rd.s+1358);
-    Ra.sl[3]=1253; /* line # 1253 */
+    Ra.sl[3]=1291; /* line # 1291 */
+    P_err_init(Rd.s+1341);
+    P_src_init(Rd.s+1362,Rd.s+1369);
+    Ra.sl[3]=1296; /* line # 1296 */
     if (V_src_control==NULL) {
       V_error_result=4;
       V_emergency_stop=1;
       PAS__SELECT_OUT(PAS__f_output);
-      PAS__WRITE_STR(Rd.s+1376,-1,-1,32);
-      PAS__WRITE_STR(Rd.s+1358,-1,-1,32);
-      PAS__WRITE_STR(Rd.s+1400,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1387,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1369,-1,-1,32);
+      PAS__WRITE_STR(Rd.s+1411,-1,-1,32);
       PAS__WRITE_EOLN();
     }
     else {
-      Ra.sl[3]=1264; /* line # 1264 */
+      Ra.sl[3]=1307; /* line # 1307 */
       PAS_INSMBOL_set_keyword_tree();
       V_proc_seq=0;
       V_srf_free=NULL;
       V_srf_list=NULL;
-      Ra.sl[3]=1271; /* line # 1271 */
+      Ra.sl[3]=1314; /* line # 1314 */
       P_ide_init();
       P_set_srcfilespc(1);
-      Ra.sl[3]=1277; /* line # 1277 */
+      Ra.sl[3]=1320; /* line # 1320 */
       V_sy_ch=32;
       V_sy_label_flag=0;
     }
   }
   else {
-    Ra.sl[3]=1285; /* line # 1285 */
+    Ra.sl[3]=1328; /* line # 1328 */
     V_error_result=4;
     V_emergency_stop=1;
     PAS__SELECT_OUT(PAS__f_output);
-    PAS__WRITE_STR(Rd.s+1417,-1,-1,32);
-    PAS__WRITE_STR(Rd.s+1274,-1,-1,32);
-    PAS__WRITE_STR(Rd.s+1441,-1,-1,32);
+    PAS__WRITE_STR(Rd.s+1428,-1,-1,32);
+    PAS__WRITE_STR(Rd.s+1285,-1,-1,32);
+    PAS__WRITE_STR(Rd.s+1452,-1,-1,32);
     PAS__WRITE_EOLN();
   }
   PAS__curr_cntx=Ra.v[0];
